@@ -278,6 +278,8 @@ if ctx.mode == 'configure':
     ctx.subst_file("${TOP_DIR}/roxterm-config.1.xml.in",
             "${BUILD_DIR}/roxterm-config.1.xml", True)
     ctx.subst_file("${TOP_DIR}/roxterm.spec.in", "${BUILD_DIR}/roxterm.spec")
+    ctx.subst_file("${TOP_DIR}/.ycm_extra_conf.py.in",
+            "${TOP_DIR}/.ycm_extra_conf.py", True)
     ctx.setenv('APPINFO_STRING', "${VERSION} (%s)" % \
             time.strftime("%Y-%m-%d", time.gmtime(time.time())))
     if not os.path.exists(ctx.subst(APPINFO)):
@@ -703,7 +705,8 @@ elif ctx.mode == 'dist':
             "roxterm.appdata.xml.in " \
             "roxterm.desktop roxterm.lsm.in roxterm.spec.in " \
             "roxterm.svg roxterm.xml TODO " \
-            "src/roxterm-config.glade src/roxterm-config.ui")
+            "src/roxterm-config.glade src/roxterm-config.ui " \
+            ".ycm_extra_conf.py.in")
     ctx.add_dist([f.replace("${TOP_DIR}/", "") \
             for f in [LOGO_PNG, FAVICON, TEXT_LOGO]])
     ctx.add_dist(ctx.glob("*.[c|h]", os.curdir, "src"))
