@@ -244,9 +244,7 @@ static GOptionEntry global_g_options[] = {
         G_OPTION_ARG_CALLBACK, global_options_set_string,
         N_("Use the named keyboard shortcut scheme"),
         N_("SCHEME") },
-    { "colour_scheme", 'c', G_OPTION_FLAG_HIDDEN,
-        G_OPTION_ARG_CALLBACK, global_options_set_string, NULL, NULL },
-    { "shortcut_scheme", 'c', G_OPTION_FLAG_HIDDEN,
+    { "colour_scheme", 0, G_OPTION_FLAG_HIDDEN,
         G_OPTION_ARG_CALLBACK, global_options_set_string, NULL, NULL },
     { "maximise", 'm', G_OPTION_FLAG_IN_MAIN,
         G_OPTION_ARG_NONE, &global_options_maximise,
